@@ -9,8 +9,8 @@
  *   (at your option) any later version.                                   * 
  ***************************************************************************/
 
-#ifndef KTVIEW_H
-#define KTVIEW_H
+#ifndef CRONTABWIDGET_H
+#define CRONTABWIDGET_H
 
 #include <QWidget>
 
@@ -55,7 +55,7 @@ public:
 	QList<QAction*> cutCopyPasteActions();
 	QAction* printAction();
 	
-public slots:
+public Q_SLOTS:
 	
 	/**
 	 * Copies variables and/or tasks.
@@ -74,7 +74,7 @@ public slots:
 	 */
 	void print();
 
-protected slots:
+protected Q_SLOTS:
 
 	void refreshCron();
 
@@ -115,4 +115,4 @@ private:
 	
 };
 
-#endif // KTVIEW_H
+#endif // CRONTABWIDGET_H
